@@ -8,7 +8,6 @@ import pandas as pd
 
 from pydrive.auth import GoogleAuth
 from pydrive.drive import GoogleDrive
-#from google.colab import auth
 from oauth2client.client import GoogleCredentials
 
 
@@ -36,6 +35,20 @@ def setup_logging():
 LOGGER = setup_logging()
 
 
+class Configuration(object):
+
+    def __init__(self):
+        self.config = None
+        self.configString = ""
+
+    def configure_parameters(self, config):
+        
+        for item in config:
+            self.configString += item + " "
+            self.configString += config[item] + " "
+
+        return self.configString
+
 class QueryJobConfig(object):
 
     def __init__(self):
@@ -88,8 +101,8 @@ class Client(object):
     def __init__(self, usernameDriveAuth=None):
         self._logger = logging.getLogger("sQ")
         self._usernameDriveAuth = usernameDriveAuth
-        self._username = usernameDriveAuth if usernameDriveAuth else os.getenv("SUPERQUERY_USERNAME")
-        self._password = None if usernameDriveAuth else os.getenv("SUPERQUERY_PASSWORD")
+        self._username = os.getenv("SUPERQUERY_USERNAME")
+        self._password = os.getenv("SUPERQUERY_PASSWORD") 
         self._user_agent = "python"
         self._project = None
         self._destination_dataset = None
@@ -102,12 +115,13 @@ class Client(object):
     
     def get_colab_auth_from_drive(self, usernameDriveAuth):
         user_auth = None
+        self._logger.debug("Trying to get auth file from Google Drive")
         try:
-            from google.colab import drive
-            # auth.authenticate_user()
-            # gauth = GoogleAuth()
-            # gauth.credentials = GoogleCredentials.get_application_default()
-            # drive = GoogleDrive(auth)
+            from google.colab import auth
+            auth.authenticate_user()
+            gauth = GoogleAuth()
+            gauth.credentials = GoogleCredentials.get_application_default()
+            drive = GoogleDrive(gauth)
 
             file_list = drive.ListFile().GetList()
             user_auth = None
@@ -116,12 +130,20 @@ class Client(object):
                 if f['title'] == "auth.json":
                     fname = f['title']
                     f_ = drive.CreateFile({'id': f['id']})
-                    print("[sQ] Got auth file!")
+
+                    self._logger.debug("Got auth file!")
                     user_auth = f_.GetContentString(fname)
-
                     self._username = usernameDriveAuth
-                    self._password = json.loads(user_auth)['password']
+                    self._password = json.loads(user_auth)['value']
 
+                    self._logger.debug("Saving auth to environment")
+                    os.environ['SUPERQUERY_USERNAME'] = self._username
+                    os.environ['SUPERQUERY_PASSWORD'] = self._password
+
+                    # self._logger.debug("Removing auth file!")
+                    # f_.Trash()  # Move file to trash.
+                    # f_.UnTrash()  # Move file out of trash.
+                    # f_.Delete()  # Permanently delete the file.
                     break;
 
         except Exception as e:
@@ -164,7 +186,7 @@ class Client(object):
         if job_config is not None:
             raise NotImplementedError("The job_config parameter is not yet handled")
 
-        if self._usernameDriveAuth:
+        if (self._username is None or self._password is None) and self._usernameDriveAuth:
             self.get_colab_auth_from_drive(self._usernameDriveAuth)
         
         username = username or self._username
@@ -203,6 +225,8 @@ class Client(object):
                     stats = json.loads(explain[0]["statistics"])
                     #job_reference = json.loads(explain[0]["jobReference"])
                 self.result = Result(cursor, stats)
+                savings = (float(stats['bigQueryTotalBytesProcessed']) - float(stats['superQueryTotalBytesProcessed'])) / float(stats['bigQueryTotalBytesProcessed']) * 100
+                print("[sQ] Cost: ${0}, superQuery saved you: {1}%, Speedup: {2}X".format(round(stats['superQueryTotalBytesProcessed']/1024**4 * 5,4), str( round(savings , 2)), round(1/(1-((savings if savings < 100 else savings-1)/100)),2)))
                 return self.result
 
         except Exception as e:
